@@ -1,6 +1,5 @@
-from __future__ import absolute_import
-
 from functools import partial
+import pickle
 
 import numpy as np
 import pandas as pd
@@ -8,7 +7,6 @@ from pandas.core.internals import create_block_manager_from_blocks, make_block
 
 from . import numpy as pnp
 from .core import Interface
-from .compatibility import pickle
 from .encode import Encode
 from .utils import extend, framesplit, frame
 
@@ -47,11 +45,11 @@ class PandasColumns(Interface):
 
         # TODO: don't use values, it does some work.  Look at _blocks instead
         #       pframe/cframe do this well
-        arrays = dict((extend(k, col), df[col].values)
+        arrays = {extend(k, col): df[col].values
                        for k, df in data.items()
-                       for col in df.columns)
-        arrays.update(dict((extend(k, '.index'), df.index.values)
-                            for k, df in data.items()))
+                       for col in df.columns}
+        arrays.update({extend(k, '.index'): df.index.values
+                            for k, df in data.items()})
         # TODO: handle categoricals
         self.partd.append(arrays, **kwargs)
 
@@ -110,7 +108,10 @@ def index_to_header_bytes(ind):
         cat = None
         values = ind.values
 
-    header = (type(ind), ind._get_attributes_dict(), values.dtype, cat)
+    if is_extension_array_dtype(ind):
+        return None, dumps(ind)
+
+    header = (type(ind), {k: getattr(ind, k, None) for k in ind._attributes}, values.dtype, cat)
     bytes = pnp.compress(pnp.serialize(values), values.dtype)
     return header, bytes
 
@@ -182,7 +183,7 @@ def serialize(df):
     headers = [col_header, ind_header]
     bytes = [col_bytes, ind_bytes]
 
-    for block in df._data.blocks:
+    for block in df._mgr.blocks:
         h, b = block_to_header_bytes(block)
         headers.append(h)
         bytes.append(b)
